import { lazy, ReactNode, useState } from 'react'
import { Card, Flex } from 'antd'
import AIChat from '@/components/ai/AIChat'
import DataRender from './DataRender'
import { useDataQuery } from '@/hooks/useQuery'

const ViewDataFiledButtonModal = lazy(() => import('./ViewDataFiledButtonModal'))

export default function DataWrap({
  hasAI = true,
  title,
  headerRender,
  buttons,
  empty,
}: {
  title: string
  buttons?: ReactNode
  headerRender?: (data: any) => ReactNode
  empty?: ReactNode
  hasAI?: boolean
}) {
  const [pagination, setPagination] = useState({ page: 1, 'per-page': 100 })
  const { data, isPending } = useDataQuery(pagination)

  const columns: any = data.title.map((item: any) => {
    return {
      title: item.name,
      dataIndex: item.english_name,
      align: 'center',
      minWidth: 120,
    }
  })

  const handleTableChange = (pagination: any) => {
    setPagination({ page: pagination.current, 'per-page': pagination.pageSize })
  }

  const Header = () => {
    if (headerRender) return headerRender(data)
    return (
      <Flex justify="space-between" style={{ marginBottom: '20px' }}>
        <Flex wrap gap={10}>
          {buttons}
        </Flex>
        <ViewDataFiledButtonModal></ViewDataFiledButtonModal>
      </Flex>
    )
  }
  return (
    <Flex gap={20} style={{ height: '100%' }}>
      <Card className="app-card" title={title} style={{ flex: 1, overflowX: 'hidden' }}>
        {empty && !data.info ? (
          empty
        ) : (
          <>
            <Header />
            <DataRender
              rowKey={'pk_id'}
              loading={isPending}
              dataSource={data.list}
              pagination={{ total: data.total, current: pagination.page, pageSize: pagination['per-page'] }}
              columns={columns}
              onChange={handleTableChange}
            />
          </>
        )}
      </Card>
      {hasAI && <AIChat />}
    </Flex>
  )
}
