import { useState } from 'react'
import { Button, Checkbox, Flex, Modal, Steps, Radio, Select, Input, Form } from 'antd'
import { useDataFieldQuery } from '@/hooks/useQuery'

export default function ButtonModal() {
  const { data } = useDataFieldQuery()

  const [open, setOpen] = useState(false)
  const [current, setCurrent] = useState(0)
  const [checkedList, setCheckedList] = useState<string[]>([])
  const [processingMethod, setProcessingMethod] = useState<'unified' | 'individual'>('unified')
  const [processingRule, setProcessingRule] = useState<string>('不处理')
  const [specialValue, setSpecialValue] = useState<string>('')
  const plainOptions = data?.map((item) => {
    return {
      label: item.name,
      value: item.name,
    }
  })
  const onChange = (list: string[]) => {
    setCheckedList(list)
  }

  const next = () => {
    setCurrent(current + 1)
  }

  const prev = () => {
    setCurrent(current - 1)
  }

  const [form] = Form.useForm()

  const methodOptions = [
    { label: '统一规则处理', value: 'unified' },
    { label: '逐个配置规则处理', value: 'individual' },
  ]

  const ruleOptions = [
    { label: '不处理', value: '不处理' },
    { label: 'AI智能填充', value: 'AI智能填充' },
    { label: '删除', value: '删除' },
    { label: '平均值填充', value: '平均值填充' },
    { label: '特殊值填充', value: '特殊值填充' },
    { label: '热卡填充（上）', value: '热卡填充（上）' },
    { label: '热卡填充（下）', value: '热卡填充（下）' },
  ]

  const steps = [
    {
      title: '请选择重复值数据',
      content: <Checkbox.Group options={plainOptions} value={checkedList} onChange={onChange} />,
    },
    {
      title: '配置处理规则',
      content: (
        <Form form={form} labelCol={{ span: 5 }} preserve={false}>
          <Form.Item label="重复值处理字段">是否会员、会员等级</Form.Item>
          <Form.Item label="重复值字段处理方法">
            <Radio.Group
              onChange={(e) => setProcessingMethod(e.target.value)}
              value={processingMethod}
              options={methodOptions}></Radio.Group>
          </Form.Item>
          <Form.Item label="重复值字段处理规则">
            <Select
              style={{ width: 200 }}
              value={processingRule}
              onChange={(value) => setProcessingRule(value)}
              options={ruleOptions}
            />
          </Form.Item>
          <Form.Item label="请填写特殊值">
            <Input
              style={{ width: 200 }}
              value={specialValue}
              onChange={(e) => setSpecialValue(e.target.value)}
              placeholder="请输入"
            />
          </Form.Item>
        </Form>
      ),
    },
    {
      title: '处理执行',
      content: (
        <>
          <p>重复值处理字段：XXXXX, XXXX, XXXX, XXXX, XXXX, XXXX</p>
          <Flex vertical align="center" style={{ marginTop: '20px' }}>
            <Button type="primary">开始处理</Button>
            <Steps
              labelPlacement="vertical"
              items={[
                {
                  title: '检查字段处理规则',
                },
                {
                  title: '重复值处理',
                },
                {
                  title: '处理结果',
                },
              ]}></Steps>
          </Flex>
        </>
      ),
    },
  ]

  const title = steps[current].title

  return (
    <>
      <Button type="primary" onClick={() => setOpen(true)}>
        处理重复值
      </Button>
      <Modal
        title={title}
        open={open}
        footer={
          <Flex justify="center" gap={20}>
            {current === 0 && <Button type="primary">检查重复值字段</Button>}
            {current > 0 && <Button onClick={() => prev()}>上一步</Button>}
            {current < steps.length - 1 && (
              <Button type="primary" onClick={() => next()}>
                下一步
              </Button>
            )}
            {current === steps.length - 1 && (
              <Button type="primary" onClick={() => setOpen(false)}>
                关闭
              </Button>
            )}
          </Flex>
        }
        destroyOnClose
        width={800}
        onCancel={() => setOpen(false)}>
        <div style={{ minHeight: 300, padding: '20px 0' }}>
          <div style={{ marginTop: '20px' }}>{steps[current].content}</div>
        </div>
      </Modal>
    </>
  )
}
