import { useState } from 'react'
import { Button, Divider, Flex, Modal, Steps } from 'antd'
import { useNavigate } from 'react-router'

export default function ButtonModal() {
  const navigate = useNavigate()
  const [open, setOpen] = useState(false)
  const [current, setCurrent] = useState(0)

  const next = () => {
    setCurrent(current + 1)
  }

  const prev = () => {
    setCurrent(current - 1)
  }

  const steps = [
    {
      title: '探索重复值',
    },
    {
      title: '处理重复值',
    },
  ]

  return (
    <>
      <Button type="primary" onClick={() => setOpen(true)}>
        重复值
      </Button>
      <Modal
        title="重复值探索"
        open={open}
        footer={
          <Flex justify="center" gap={20}>
            {current === 0 && <Button type="primary">智能探索重复值字段</Button>}

            {current > 0 && <Button onClick={() => prev()}>上一步</Button>}
            {current < steps.length - 1 && (
              <Button type="primary" onClick={() => next()}>
                下一步
              </Button>
            )}
            {current === steps.length - 1 && (
              <Button type="primary" onClick={() => navigate('/data/preprocess/repeat')}>
                跳转数据预处理
              </Button>
            )}
          </Flex>
        }
        destroyOnClose
        width={800}
        onCancel={() => setOpen(false)}>
        <div style={{ minHeight: 300, padding: '40px 0' }}>
          <Steps current={current} labelPlacement="vertical" items={steps} />
          <Divider />
          <Flex justify="space-between">探索结果：</Flex>
          <Divider dashed />
          <p>1、第XX行、第XX行的数据完全一样</p>
          <p>2、第XX行、第XX行、第XX行的数据完全一样</p>
        </div>
      </Modal>
    </>
  )
}
